function [ Z, RHO, V ] = SRK(x,T,P,Phase,compData )
% This is a remake of Andreas Linhart and Sigurd Skogestads
% implementation of the SRK-EOS and is adapted for specialization project
% fall 2015.

%Author: Torstein Bishop, Department of Chemical Engineering, NTNU. Fall
%2015.

% IN: molefraction of mixture (x), Pressure (P) [Pa], Temperature [K],
% phase of mixture and various component data (Tc,Pc, CP, w).

%OUT: Compressibility, Z, and density, rho, [kg/m3].

% Checking for number of components and gathering compData
NC = length(x);

%Checking for consistent mole fractions
if NC == 1 && sum(x) <1
    disp('Inconsistent mole fractions')
end

%Here: SRK binary interaction parameters set to zero
kinteraction=zeros(NC,NC);

% initialize
% liquid=1;vapor=2; Not sure if this part is needed
R = 8.314; % [J/K*mol]

Pc=compData.Pc; %Critical Pressure
Tc=compData.Tc; %Critical Temperature
w=compData.w;   % Acentric factor
ZRA=0.29056-0.08775*w;  % Rackett compressibility factor.
Cp=compData.Cp;
Tref=compData.Tref; % Reference temperature
Mm=compData.Mm/1000; % Molar mass for the components 

% Calculating important parameters needed to solve system
Tre=T./Tc;
Pre=P./Pc;
m=0.480+1.574.*w-0.176.*w.^2;
a=(1+m.*(1-Tre.^0.5)).^2;
Ap=0.42747.*a.*Pre./Tre.^2;
Bp=0.08664.*Pre./Tre;


% Start calculations
% Binary a's:
Ab=zeros(NC,NC);
for i=1:NC
    for j=1:NC
        Ab(i,j)=(Ap(i)*Ap(j))^0.5;
    end
end
% Mixture a and b
A=0;
for i=1:NC
    for j=1:NC
        A=A+x(i)*x(j)*Ab(i,j)*(1-kinteraction(i,j));
    end
end
B=0;
for i=1:NC
    B=B+x(i)*Bp(i);
end

% Solve cubic equation to find compressibility Z = P*V/(R*T)
Zall=roots([1 -1 A-B-B^2 -A*B]);  
% use real roots only
        Zreal=[];
	for i=1:3 
	  if isreal(Zall(i))==1 
            Zreal=[Zreal Zall(i)]; 
	  end 
    end
    
    %disp(Zreal)
% Select right root depending on phase
if     strcmp(Phase,'liquid')  
    Z=min(Zreal);
elseif strcmp(Phase,'vapor')   
    Z=max(Zreal);
else
    disp('error in specifying phase')
end


% Density (more precisely: molar volume)
MM = 0;
if strcmp(Phase,'liquid')%Correct liquid SRK-volume using Peneleoux... 
    %correction
     c=0;
     for i=1:NC
     c=c+x(i) * (0.40768 * (0.29441 - ZRA(i)) * (R * Tc(i)) / (Pc(i))) ;
     end
   V = ((Z * R * T / P)- c);
     for i = 1:NC % Loop to calculate average Molar Mass
         MM = MM + x(i)*Mm(i);
     end
     
     RHO = MM/V;
     
else  % vapor
   V = Z * R * T / P;
   
    for i = 1:NC % Loop to calculate average Molar Mass
         MM = MM + x(i)*Mm(i);
    end
   
   RHO = MM/V; %Calculating the density
end
end

