function [vr]=swirl_sep2_deliq(t,x,in)
qin=in(1);
Ro=in(2);
Ri=in(3);
Vg_in=in(4);
ta=in(5);
rin=in(6);
FS=in(7);

% Filling in component data needed to calculate the density of the gas
% found from The properties of Gases and Liquids fifth edition.
compData.Pc = 45.99e5; % [Pa], Critical Pressure
compData.Tc = 190.56;  % [K], Critical Temperature
compData.w = 0.011;     % Acentric factor
compData.Cp = 0;       % Not used in any calculations yet
compData.Tref = 273.15; % [K]
compData.Mm = 16.043;   % [g/mol]

P = 50e5; % [Pa] Pressure in separation system
T = 50+273; % [K] Assumed temperature in separation system
y = 1; % Assume only methane in gas phase

% Calling SRK-EOS for density calculations
[Z, RHO] = SRK(y, T, P, 'vapor', compData);

rhog=RHO; %kg/m^3, density for gas
rhoo=881; %kg/m^3, density for oil 


r=x(1);

Rc=0.25*Ro; %Critical radius
va=qin/(pi*Ro^2); % Initial axial velocity

k=0.1; % Swirl number 

vt0=k*va; %Initial tangential velocity

rd = (-0.6*(qin*3600)*1E-6+0.0002)/2; % Droplet size

Visc_gas = 0.00001118; % Gas viscosity 

mum=Visc_gas;

%Smooth centrifugal acceleration
f2=(vt0*exp(-0.04*va*t/(2*Ro)))^2/r;
f1=(vt0*exp(-0.04*va*t/(2*Ro))/Rc)^2*r;
f=f2-f1; 
beta=1; %Smoothing parameter
ac=f2-0.5*((f^2+beta^2)^.5+f); %Centrifugal acceleration


%Radial velocity of droplet
 vr=(2/9*(rhoo-rhog)*rd^2/mum)*ac; %Original model

end

